@@ -1,4 +1,7 @@
 from .clusters import ClustersClient
+from .dataset_client import DatasetsClient
+from .dataset_tag_client import DatasetTagsClient
+from .dataset_version_client import DatasetVersionsClient
 from .deployment_client import DeploymentsClient
 from .experiment_client import ExperimentsClient
 from .hyperparameter_client import HyperparameterJobsClient
@@ -9,5 +12,6 @@ from .model_client import ModelsClient
 from .notebook_client import NotebooksClient
 from .project_client import ProjectsClient
 from .secret_client import SecretsClient
+from .storage_provider_client import StorageProvidersClient
 from .sdk_client import SdkClient
 from .tensorboards_client import TensorboardClient
