@@ -1,5 +1,5 @@
 from . import DeploymentsClient, ExperimentsClient, HyperparameterJobsClient, ModelsClient, ProjectsClient, \
-    MachinesClient, NotebooksClient
+    MachinesClient, NotebooksClient, SecretsClient
 from .job_client import JobsClient
 from .. import logger as sdk_logger
 
@@ -18,3 +18,4 @@ class SdkClient(object):
         self.projects = ProjectsClient(api_key=api_key, logger=logger)
         self.machines = MachinesClient(api_key=api_key, logger=logger)
         self.notebooks = NotebooksClient(api_key=api_key, logger=logger)
+        self.secrets = SecretsClient(api_key=api_key, logger=logger)
