@@ -177,6 +177,14 @@ def common_experiments_create_options(f):
 
 def dataset_options(f):
     options = [
+        click.option(
+            "--datasetId",
+            "dataset_id_list",
+            metavar="<dateset id>",
+            multiple=True,
+            help="Dataset ID",
+            cls=common.GradientDatasetOption,
+        ),
         click.option(
             "--datasetUri",
             "dataset_uri_list",
@@ -208,6 +216,13 @@ def dataset_options(f):
             help="S3 bucket's Secret Access Key",
             cls=common.GradientDatasetOption,
         ),
+        click.option(
+            "--datasetAwsEndpoint",
+            "dataset_endpoint_list",
+            multiple=True,
+            help="S3 endpoint URL",
+            cls=common.GradientDatasetOption,
+        ),
         click.option(
             "--datasetVersionId",
             "dataset_version_id_list",
