@@ -1,6 +1,5 @@
 import abc
 import json
-import pydoc
 
 import click
 import six
@@ -14,9 +13,10 @@ from gradient.api_sdk.config import config
 from gradient.api_sdk.utils import concatenate_urls
 from gradient.cli_constants import CLI_PS_CLIENT_NAME
 from gradient.clilogger import CliLogger
-from gradient.cliutils import get_terminal_lines, none_strings_to_none_objects
+from gradient.cliutils import none_strings_to_none_objects
 from gradient.commands import tensorboards as tensorboards_commands
-from gradient.commands.common import BaseCommand, ListCommandMixin, DetailsCommandMixin, StreamMetricsCommand
+from gradient.commands.common import BaseCommand, ListCommandMixin, DetailsCommandMixin, StreamMetricsCommand, \
+    LogsCommandMixin
 
 try:
     # Python 3
@@ -28,8 +28,6 @@ except ImportError:
 
 @six.add_metaclass(abc.ABCMeta)
 class BaseExperimentCommand(BaseCommand):
-    entity = "experiment"
-
     def _get_client(self, api_key, logger):
         client = api_sdk.clients.ExperimentsClient(
             api_key=api_key,
@@ -110,7 +108,7 @@ class BaseCreateExperimentCommandMixin(object):
         return experiment_id
 
     def get_instance_url(self, instance_id, project_id):
-        url = concatenate_urls(config.WEB_URL, "console/projects/{}/experiments/{}".format(project_id, instance_id))
+        url = concatenate_urls(config.WEB_URL, "projects/{}/experiments/{}".format(project_id, instance_id))
         return url
 
     def _handle_workspace(self, instance_dict):
@@ -120,7 +118,7 @@ class BaseCreateExperimentCommandMixin(object):
         instance_dict.pop("workspace", None)
         instance_dict.pop("workspace_archive", None)
         instance_dict.pop("workspace_url", None)
-        if handler and handler != "none":
+        if handler:
             instance_dict["workspace_url"] = handler
 
     def _maybe_add_to_tensorboard(self, tensorboard_id, experiment_id, api_key):
@@ -138,9 +136,11 @@ class BaseCreateExperimentCommandMixin(object):
         """Make list of dataset dicts"""
         datasets = [
             json_.pop("dataset_uri_list", ()),
+            json_.pop("dataset_id_list", ()),
             json_.pop("dataset_name_list", ()),
             json_.pop("dataset_access_key_id_list", ()),
             json_.pop("dataset_secret_access_key_list", ()),
+            json_.pop("dataset_endpoint_list", ()),
             json_.pop("dataset_version_id_list", ()),
             json_.pop("dataset_etag_list", ()),
             json_.pop("dataset_volume_kind_list", ()),
@@ -150,25 +150,27 @@ class BaseCreateExperimentCommandMixin(object):
         if not any(datasets):
             return
         else:
-            dataset_uri_len = len(datasets[0])
-            other_dataset_param_max_len = max(len(elem) for elem in datasets[1:])
-            if dataset_uri_len < other_dataset_param_max_len:
+            datasets_len = max(len(datasets[0]), len(datasets[1]))
+            other_dataset_param_max_len = max(len(elem) for elem in datasets[2:])
+            if datasets_len < other_dataset_param_max_len:
                 # there no point in defining n+1 dataset parameters of one type for n datasets
                 raise click.BadParameter(
                     "Too many dataset parameter sets ({}) for {} dataset URIs. Forgot to add one more dataset URI?"
-                        .format(other_dataset_param_max_len, dataset_uri_len))
+                        .format(other_dataset_param_max_len, datasets_len))
 
         datasets = [none_strings_to_none_objects(d) for d in datasets]
 
         datasets = zip_longest(*datasets, fillvalue=None)
         datasets = [{"uri": dataset[0],
-                     "name": dataset[1],
-                     "aws_access_key_id": dataset[2],
-                     "aws_secret_access_key": dataset[3],
-                     "version_id": dataset[4],
-                     "etag": dataset[5],
-                     "volume_kind": dataset[6],
-                     "volume_size": dataset[7],
+                     "id": dataset[1],
+                     "name": dataset[2],
+                     "aws_access_key_id": dataset[3],
+                     "aws_secret_access_key": dataset[4],
+                     "aws_endpoint": dataset[5],
+                     "version_id": dataset[6],
+                     "etag": dataset[7],
+                     "volume_kind": dataset[8],
+                     "volume_size": dataset[9],
                      } for dataset in datasets]
 
         json_["datasets"] = datasets
@@ -374,32 +376,7 @@ class GetExperimentCommand(DetailsCommandMixin, BaseExperimentCommand):
         return data
 
 
-class ExperimentLogsCommand(BaseExperimentCommand):
-    def execute(self, experiment_id, line, limit, follow):
-        if follow:
-            self.logger.log("Awaiting logs...")
-            self._log_logs_continuously(experiment_id, line, limit)
-        else:
-            self._log_table_of_logs(experiment_id, line, limit)
-
-    def _log_table_of_logs(self, experiment_id, line, limit):
-        logs = self.client.logs(experiment_id, line, limit)
-        if not logs:
-            self.logger.log("No logs found")
-            return
-
-        table_str = self._make_table(logs, experiment_id)
-        if len(table_str.splitlines()) > get_terminal_lines():
-            pydoc.pager(table_str)
-        else:
-            self.logger.log(table_str)
-
-    def _log_logs_continuously(self, experiment_id, line, limit):
-        logs_gen = self.client.yield_logs(experiment_id, line, limit)
-        for log in logs_gen:
-            log_msg = "{}\t{}\t{}".format(*self._format_row(experiment_id, log))
-            self.logger.log(log_msg)
-
+class ExperimentLogsCommand(LogsCommandMixin, BaseExperimentCommand):
     def _make_table(self, logs, experiment_id):
         table_title = "Experiment %s logs" % experiment_id
         table_data = [("JOB ID", "LINE", "MESSAGE")]
@@ -410,11 +387,15 @@ class ExperimentLogsCommand(BaseExperimentCommand):
 
         return table.table
 
+    def _get_log_row_string(self, id, log):
+        log_msg = "{}\t{}\t{}".format(*self._format_row(id, log))
+        return log_msg
+
     @staticmethod
     def _format_row(experiment_id, log_row):
         return (style(fg="blue", text=experiment_id),
                 style(fg="red", text=str(log_row.line)),
-                str(log_row.message).rstrip())
+                log_row.message)
 
 
 class DeleteExperimentCommand(BaseExperimentCommand):
@@ -425,13 +406,13 @@ class DeleteExperimentCommand(BaseExperimentCommand):
 
 class ExperimentAddTagsCommand(BaseExperimentCommand):
     def execute(self, experiment_id, *args, **kwargs):
-        self.client.add_tags(experiment_id, entity=self.entity, **kwargs)
+        self.client.add_tags(experiment_id, **kwargs)
         self.logger.log("Tags added to experiment")
 
 
 class ExperimentRemoveTagsCommand(BaseExperimentCommand):
     def execute(self, experiment_id, *args, **kwargs):
-        self.client.remove_tags(experiment_id, entity=self.entity, **kwargs)
+        self.client.remove_tags(experiment_id, **kwargs)
         self.logger.log("Tags removed from experiment")
 
 
